@@ -1,6 +1,6 @@
 package App::Greple::xlate;
 
-our $VERSION = "0.41";
+our $VERSION = "0.4101";
 
 =encoding utf-8
 
@@ -16,7 +16,7 @@ App::Greple::xlate - translation support module for greple
 
 =head1 VERSION
 
-Version 0.41
+Version 0.4101
 
 =head1 DESCRIPTION
 
@@ -233,8 +233,8 @@ You can recover the original file by next L<sed(1)> command.
 
 =item B<colon>, I<:::::::>
 
-Original and converted text are printed in the markdown B<div> block
-style notation.
+The original and translated text are output in a markdown's custom
+container style.
 
     ::::::: ORIGINAL
     original text
@@ -243,7 +243,7 @@ style notation.
     translated Japanese text
     :::::::
 
-This means:
+Above text will be translated to the following in HTML.
 
     <div class="ORIGINAL">
     original text
@@ -443,6 +443,10 @@ command from Emacs editor.  C<xlate-region> function translate the
 given region.  Default language is C<EN-US> and you can specify
 language invoking it with prefix argument.
 
+=for html <p>
+<img width="750" src="https://raw.githubusercontent.com/kaz-utashiro/App-Greple-xlate/main/images/emacs.png">
+</p>
+
 =head1 ENVIRONMENT
 
 =over 7
